@@ -38,6 +38,7 @@ import types
 
 import pygame
 import pygame.gfxdraw as gfxdraw
+
 import pygame_menu.baseimage as _baseimage
 import pygame_menu.controls as _controls
 import pygame_menu.events as _events
@@ -89,7 +90,11 @@ class Menu(object):
     :type screen_dimension: tuple, list, None
     :param theme: Menu theme object, if None use the default theme
     :type theme: :py:class:`pygame_menu.themes.Theme`
-    :param kwargs: Optional keyword-parameters
+    :param touchscreen_enabled: Enable/disable touch action inside the Menu
+    :type touchscreen_enabled: bool
+    :param touchscreen_motion_selection: Select widgets using touchscreen motion
+    :type touchscreen_motion_selection: bool
+    :param kwargs: Optional keyword arguments
     :type kwargs: dict
     """
 
@@ -112,24 +117,30 @@ class Menu(object):
                  rows=None,
                  screen_dimension=None,
                  theme=_themes.THEME_DEFAULT,
+                 touchscreen_enabled=False,
+                 touchscreen_motion_selection=False,
                  **kwargs
                  ):
         assert isinstance(height, (int, float))
         assert isinstance(width, (int, float))
+        # assert isinstance(title, str)
+
         assert isinstance(center_content, bool)
         assert isinstance(column_force_fit_text, bool)
         assert isinstance(column_max_width, (tuple, type(None), (int, float), list))
         assert isinstance(columns, int)
         assert isinstance(enabled, bool)
         assert isinstance(joystick_enabled, bool)
-        assert isinstance(menu_position, (tuple, list))
         assert isinstance(menu_id, str)
+        assert isinstance(menu_position, (tuple, list))
         assert isinstance(mouse_enabled, bool)
         assert isinstance(mouse_motion_selection, bool)
         assert isinstance(mouse_visible, bool)
         assert isinstance(rows, (int, type(None)))
         assert isinstance(screen_dimension, (tuple, list, type(None)))
         assert isinstance(theme, _themes.Theme), 'theme bust be an pygame_menu.themes.Theme object instance'
+        assert isinstance(touchscreen_enabled, bool)
+        assert isinstance(touchscreen_motion_selection, bool)
 
         # Assert theme
         theme.validate()
@@ -263,7 +274,14 @@ class Menu(object):
         self._mouse_visible = mouse_visible
         self._mouse_visible_default = mouse_visible
 
-        # Create Menu bar (title)
+        # Init touchscreen
+        if touchscreen_enabled:
+            version_major, _, _ = pygame.version.vernum
+            assert version_major >= 2, 'touchscreen is only supported in pygame v2+'
+        self._touchscreen = touchscreen_enabled
+        self._touchscreen_motion_selection = touchscreen_motion_selection
+
+        # Create menubar (title)
         self._menubar = _widgets.MenuBar(
             back_box=theme.menubar_close_button,
             background_color=self._theme.title_background_color,
@@ -289,7 +307,7 @@ class Menu(object):
             offset=self._theme.title_shadow_offset,
             position=self._theme.title_shadow_position
         )
-        self._menubar.set_controls(self._joystick, self._mouse)
+        self._menubar.set_controls(self._joystick, self._mouse, self._touchscreen)
 
         # Scrolling area
         self._widgets_surface = None
@@ -307,6 +325,7 @@ class Menu(object):
             shadow_offset=self._theme.scrollbar_shadow_offset,
             shadow_position=self._theme.scrollbar_shadow_position
         )
+        self._scroll.set_menu(self)
 
         # Upon this, no more kwargs should exist, raise exception if there's more
         for invalid_keyword in kwargs.keys():
@@ -359,7 +378,7 @@ class Menu(object):
         :type action: :py:class:`pygame_menu.Menu`, :py:class:`pygame_menu.events.MenuAction`, callable, None
         :param args: Additional arguments used by a function
         :type args: any
-        :param kwargs: Additional keyword-arguments
+        :param kwargs: Optional keyword arguments
         :type kwargs: dict
         :return: Widget object
         :rtype: :py:class:`pygame_menu.widgets.Button`
@@ -457,7 +476,7 @@ class Menu(object):
         :type onreturn: callable, None
         :param previsualization_width: Previsualization width as a factor of the height
         :type previsualization_width: int, float
-        :param kwargs: Additional keyword-parameters
+        :param kwargs: Optional keyword arguments
         :type kwargs: dict
         :return: Widget object
         :rtype: :py:class:`pygame_menu.widgets.ColorInput`
@@ -517,7 +536,7 @@ class Menu(object):
         :type scale_smooth: bool
         :param selectable: Image accepts user selection
         :type selectable: bool
-        :param kwargs: Optional keyword-arguments
+        :param kwargs: Optional keyword arguments
         :type kwargs: dict
         :return: Widget object
         :rtype: :py:class:`pygame_menu.widgets.Image`
@@ -570,7 +589,7 @@ class Menu(object):
         :type max_char: int
         :param selectable: Label accepts user selection, if not selectable long paragraphs cannot be scrolled through keyboard
         :type selectable: bool
-        :param kwargs: Optional keyword-arguments
+        :param kwargs: Optional keyword arguments
         :type kwargs: dict
         :return: Widget object or List of widgets if the text overflows
         :rtype: :py:class:`pygame_menu.widgets.Label`, list[:py:class:`pygame_menu.widgets.Label`]
@@ -663,7 +682,7 @@ class Menu(object):
         :type onreturn: callable, None
         :param selector_id: ID of the selector
         :type selector_id: str
-        :param kwargs: Additional keyword-parameters
+        :param kwargs: Optional keyword arguments
         :type kwargs: dict
         :return: Widget object
         :rtype: :py:class:`pygame_menu.widgets.Selector`
@@ -757,7 +776,7 @@ class Menu(object):
         :type textinput_id: str
         :param valid_chars: List of authorized chars, None if all chars are valid
         :type valid_chars: list
-        :param kwargs: Additional keyword-parameters
+        :param kwargs: Optional keyword arguments
         :type kwargs: dict
         :return: Widget object
         :rtype: :py:class:`pygame_menu.widgets.TextInput`
@@ -823,7 +842,7 @@ class Menu(object):
         The valid (key, value) are removed from the initial
         dictionary.
 
-        :param kwargs: Input attributes
+        :param kwargs: Optional keyword arguments (input attributes)
         :type kwargs: dict
         :return: Dictionary of valid attributes
         :rtype: dict
@@ -950,7 +969,7 @@ class Menu(object):
             position=kwargs['shadow_position'],
             offset=kwargs['shadow_offset']
         )
-        widget.set_controls(self._joystick, self._mouse)
+        widget.set_controls(self._joystick, self._mouse, self._touchscreen)
         widget.set_alignment(kwargs['align'])
         widget.set_margin(*kwargs['margin'])
         widget.set_selection_effect(selection_effect)
@@ -1637,6 +1656,45 @@ class Menu(object):
                         updated = True  # It is updated
                         break
 
+                # Touchscreen event:
+                elif self._current._touchscreen and event.type == pygame.FINGERDOWN:
+                    # If the touchscreen motion selection is disabled then select a widget by clicking
+                    if not self._current._touchscreen_motion_selection:
+                        for index in range(len(self._current._widgets)):
+                            widget = self._current._widgets[index]
+                            # Don't consider the mouse wheel (button 4 & 5)
+                            if self._current._scroll.collide(widget, event) and \
+                                    widget.is_selectable:
+                                self._current._select(index)
+
+                    # If touchscreen motion selection, clicking will disable the active state
+                    # only if the user clicked outside the widget
+                    else:
+                        if not self._current._scroll.collide(selected_widget, event):
+                            selected_widget.active = False
+
+                # Select widgets by touchscreen motion, this is valid only if the current selected widget
+                # is not active and the pointed widget is selectable
+                elif self._current._touchscreen_motion_selection and event.type == pygame.FINGERMOTION and \
+                        not selected_widget.active:
+                    for index in range(len(self._current._widgets)):
+                        widget = self._current._widgets[index]  # type: _widgets.core.Widget
+                        if self._current._scroll.collide(widget, event) and widget.is_selectable:
+                            self._current._select(index)
+
+                # Touchscreen events in selected widget
+                elif self._current._touchscreen and event.type == pygame.FINGERUP and selected_widget is not None:
+                    self._current._sounds.play_click_mouse()
+
+                    if self._current._scroll.collide(selected_widget, event):
+                        new_event = pygame.event.Event(pygame.MOUSEBUTTONUP, **event.dict)
+                        new_event.dict['origin'] = self._current._scroll.to_real_position((0, 0))
+                        finger_pos = (event.x * self._window_size[0], event.y * self._window_size[1])
+                        new_event.pos = self._current._scroll.to_world_position(finger_pos)
+                        selected_widget.update((new_event,))  # This widget can change the current Menu to a submenu
+                        updated = True  # It is updated
+                        break
+
         # Check if the menu widgets size changed, if True, updates the surface
         # forcing the rendering of all widgets
         menu_surface_needs_update = False
