@@ -56,7 +56,7 @@ class Widget(object):
     :type onreturn: callable, None
     :param args: Optional arguments for callbacks
     :type args: any
-    :param kwargs: Optional keyword-arguments for callbacks
+    :param kwargs: Optional keyword arguments
     :type kwargs: dict
     """
 
@@ -141,6 +141,7 @@ class Widget(object):
         self.selected = False
         self.selection_effect_enabled = True  # Some widgets cannot have selection effect
         self.sound = Sound()  # type: Sound
+        self.touchscreen_enabled = True
 
     def set_attribute(self, key, value):
         """
@@ -592,7 +593,7 @@ class Widget(object):
         Return the menu reference (if exists).
 
         :return: Menu reference
-        :rtype: :py:class:`pygame_menu.Menu`
+        :rtype: :py:class:`pygame_menu.Menu`, None
         """
         return self._menu
 
@@ -753,7 +754,7 @@ class Widget(object):
             x = -1
         self._shadow_tuple = (x * self._shadow_offset, y * self._shadow_offset)
 
-    def set_controls(self, joystick=True, mouse=True):
+    def set_controls(self, joystick=True, mouse=True, touchscreen=True):
         """
         Enable interfaces to control the widget.
 
@@ -761,10 +762,13 @@ class Widget(object):
         :type joystick: bool
         :param mouse: Use mouse
         :type mouse: bool
+        :param touchscreen: Use touchscreen
+        :type touchscreen: bool
         :return: None
         """
         self.joystick_enabled = joystick
         self.mouse_enabled = mouse
+        self.touchscreen_enabled = touchscreen
 
     def set_value(self, value):
         """
