@@ -74,4 +74,4 @@ class LeftArrowSelection(ArrowSelection):
              widget.get_rect().midleft[1] + self._arrow_vertical_offset)
         c = (widget.get_rect().bottomleft[0] - self._arrow_size[0] - self._arrow_right_margin,
              widget.get_rect().midleft[1] + self._arrow_size[1] / 2 + self._arrow_vertical_offset)
-        super(LeftArrowSelection, self).draw_arrow(surface, widget, a, b, c)
+        super(LeftArrowSelection, self)._draw_arrow(surface, widget, a, b, c)
