@@ -50,7 +50,7 @@ class Button(Widget):
     :type onreturn: callable, None
     :param args: Optional arguments for callbacks
     :type args: any
-    :param kwargs: Optional keyword-arguments for callbacks
+    :param kwargs: Optional keyword arguments
     :type kwargs: dict
     """
 
@@ -122,4 +122,12 @@ class Button(Widget):
                     self.apply()
                     updated = True
 
+            elif self.touchscreen_enabled and event.type == pygame.FINGERUP:
+                self.sound.play_click_mouse()
+                window_size = self.get_menu().get_window_size()
+                finger_pos = (event.x * window_size[0], event.y * window_size[1])
+                if self._rect.collidepoint(finger_pos):
+                    self.apply()
+                    updated = True
+
         return updated
